@@ -18,7 +18,6 @@ from __future__ import absolute_import
 
 import six
 import copy
-import re
 
 import google.cloud._helpers
 from google.cloud.bigquery import _helpers
@@ -27,14 +26,6 @@ from google.cloud.bigquery.routine import RoutineReference
 from google.cloud.bigquery.table import TableReference
 
 
-_PROJECT_PREFIX_PATTERN = re.compile(
-    r"""
-    (?P<project_id>\S+\:[^.]+)\.(?P<dataset_id>[^.]+)$
-""",
-    re.VERBOSE,
-)
-
-
 def _get_table_reference(self, table_id):
     """Constructs a TableReference.
 
@@ -299,13 +290,7 @@ class DatasetReference(object):
         """
         output_dataset_id = dataset_id
         output_project_id = default_project
-        with_prefix = _PROJECT_PREFIX_PATTERN.match(dataset_id)
-        if with_prefix is None:
-            parts = dataset_id.split(".")
-        else:
-            project_id = with_prefix.group("project_id")
-            dataset_id = with_prefix.group("dataset_id")
-            parts = [project_id, dataset_id]
+        parts = _helpers._split_id(dataset_id)
 
         if len(parts) == 1 and not default_project:
             raise ValueError(
