@@ -4,3 +4,6 @@ import google.api_core
 print("import: 'google.cloud.bigquery'")
 import google.cloud.bigquery
 
+print("import: 'google.cloud.bigquery_v2'")
+import google.cloud.bigquery_v2
+
